#!/bin/bash
# Aktiviert einen apt-proxy.
#
# Aufruf: mas-configure-aptproxy.sh -d | -e [Proxy-IP-Adresse]
#
# Das geht so:
# Das Skript nimmt per Argument -e oder interaktiv die Angabe eines Proxy entgegen.
# Bei der interaktiven Verwendung (-e ohne Proxy-Angabe) wird DEF_SERVER als Vorgabe
# verwendet, wenn er per Ping erreichbar ist.
# Danach wird ermittelt, ob in /etc/apt/apt.conf.d eine Datei mit Proxy-Einträgen vorhanden ist.
# Falls ja, und falls diese einen anderen Proxy enthalten, werden diese deaktiviert; sodann werden
# der Datei neue Zeilen hinzugefügt.
#
# Abschließend wird die Datei /var/run/mas-configure-aptproxy angelegt, 
# die wiederum MAS_APT_PROXY zum Inhalt hat.
#
# Beim Aufruf mit -d lesen wir aus der Datei /var/run/mas-configure-aptproxy den zuletzt
# konfigurierten Proxy.
# Ist dieser vorhanden vorhanden, werden die Proxy-Zeilen wieder deaktiviert.

FLAG=/var/run/$(basename $0 .sh)
#LISTS=$(find /etc/apt -name "*.list" -print)
CONF=$(grep -l 'Acquire::http { Proxy' /etc/apt/apt.conf.d/* | head -1)
DEF_PORT="3142"
DEF_SERVER="192.168.113.19"

show_usage() {
echo "\
$(basename $0) -d | --disable                   disable last used proxy
               -e [PROXY] | --enable [PROXY] ]  enable given proxy or prompt for it
               -m APT-LIST | --merge APT-LIST   merge last used proxy into APT-LIST"
}

if ping -c1 $DEF_SERVER >/dev/null; then
	DEF_PROXY="${DEF_SERVER}:${DEF_PORT}"
else
	DEF_PROXY=""
fi

if test $UID -ne 0; then
	echo "Dieses Skript muss von root aufgerufen werden!" >&2
	exit 9
fi

ACTION=usage
while [ $# -gt 0 ]; do
	case "$1" in
	-d|--disable)	ACTION=disable;;
	-e|--enable)	ACTION=enable;
			shift;
			MAS_APT_PROXY="$1";;
	-m|--merge)	ACTION=merge;
			shift;
			APT_LIST="${1:-nofile}";;
	*)		show_usage;
			exit;;
	esac
	shift
done

if [ ${ACTION} = "usage" ]; then
	show_usage
	exit 0
fi

if [ ${ACTION} = "enable" ]; then
	if [ -z "${MAS_APT_PROXY}" ]; then
		echo -n "Welcher apt-proxy soll gesetzt werden? 
		nur ENTER                   = Vorgabe: $DEF_PROXY
		- und ENTER                 = kein Proxy (Abbruch)
		IPv4-ADRESSE:PORT und ENTER = diesen Proxy verwenden
		Auswahl: "
		read MAS_APT_PROXY
	fi
	
	# Benutzer*in will keinen Proxy - Ende
	[ "${MAS_APT_PROXY}" = "-" ] && exit 0

	# BenutzerIn hat Vorgabe übernommen:
	[ -z "${MAS_APT_PROXY}" ] && MAS_APT_PROXY="$DEF_PROXY"
	
	# 
	# haben wir bereits einen Proxy eingestellt?
	LAST_APT_PROXY=""
	if [ -f "$FLAG" ]; then
		LAST_APT_PROXY=$(cat $FLAG)
	fi
	
#	# Endet die Eingabe mit "/"?
#	if ! [ ${MAS_APT_PROXY: -1:1} = "/" ]; then
		# ist eine Port-Angabe enthalten?
		if ! [ -z "${MAS_APT_PROXY/*:*}" ]; then
			# Default-Port hinzufügen
			MAS_APT_PROXY="${MAS_APT_PROXY}:${DEF_PORT}"
		fi
#		MAS_APT_PROXY=${MAS_APT_PROXY}/
#	fi
	
	echo -n "Aktiviere Apt-Proxy $MAS_APT_PROXY ... "
	# sed -i -e "s%http://${LAST_APT_PROXY}%http://${MAS_APT_PROXY}%g" ${LISTS} && echo -n ${MAS_APT_PROXY} > $FLAG && echo "ok." && apt-get update && exit 0
	# APT-CONF-Datei anlegen, falls noch nicht vorhanden:
	if [ -z "$CONF" ]; then
		echo "(mit Neuanlage von $CONF) ... "
		CONF=/etc/apt/apt.conf.d/01proxy
		touch "$CONF"
		chmod 644 "$CONF"
	fi

	# APT-CONF-Datei verändern, falls vorhanden:
	# unzutreffenden Proxy deaktivieren mit Triple-Raute:
	if grep '^Acquire::http { Proxy' ${CONF} | grep -q -v "${MAS_APT_PROXY}"; then
		echo -n "anderen Proxy deaktivieren..."
		sed -i -e 's%Acquire::http { Proxy\(.*\)%###Acquire::http { Proxy \1%' ${CONF} || exit 101
	fi
	# auskommentierte MAS-PROXY-Zeilen aktivieren
	if grep '^#.*Acquire::http { Proxy' ${CONF} | grep -q "${MAS_APT_PROXY}"; then
		sed -i -e "s%# Acquire::http .*${MAS_APT_PROXY}.*%Acquire::http { Proxy \"http://${MAS_APT_PROXY};\" };%" ${CONF} || exit 102
		sed -i -e 's%# Acquire::https { Proxy .*%Acquire::https { Proxy "https://"; };%' ${CONF} || exit 103
		echo "ok"
	else
	# eigene MAS-PROXY-Zeilen hinzufügen
		echo -n " anhängenen der Proxi-Zeilen ... "	
		echo -e "Acquire::http { Proxy \"http://${MAS_APT_PROXY}\"; };\nAcquire::https { Proxy \"https://\"; };" >> ${CONF}
		echo "ok"
	fi

	echo -n ${MAS_APT_PROXY} > $FLAG
	apt-get update && exit 0
	
	exit 10
fi

if [ ${ACTION} = "disable" ]; then
	if ! [ -f "$FLAG" ]; then
		echo "Datei $FLAG nicht gefunden." >&2 
		#exit 21
		if [ -r "$CONF" ]; then
			echo "Datei $FLAG nicht gefunden - untersuche $CONF ..." >&2
			MAS_APT_PROXY=$(grep '^Acquire::http { Proxy "http://' ${CONF} | cut -d/ -f3 | cut -d\" -f1)
			[ -z "${MAS_APT_PROXY}" && echo "Kein aktiver Proxy erkannt in $CONF - Abschalten des Proxy nicht möglich. Abbruch." >&2 && exit 21
		fi
	else
		MAS_APT_PROXY=$(cat $FLAG)
	fi
	
	echo -n "Deaktiviere Apt-Proxy $MAS_APT_PROXY ... "
	#sed -i -e "s%http://${MAS_APT_PROXY}%http://%g" ${LISTS} && rm -f $FLAG && echo "ok." && apt-get update && exit 0
	# vorhandene MAS-PROXY-Zeilen auskommentieren
	if grep 'Acquire::http { Proxy' ${CONF} | grep -q "${MAS_APT_PROXY}"; then
		sed -i -e "s%Acquire::http .*${MAS_APT_PROXY}.*%# Acquire::http { Proxy \"http://${MAS_APT_PROXY}\"; };%" ${CONF} || exit 202
		sed -i -e 's%Acquire::https { Proxy .*%# Acquire::https { Proxy "https://"; };%' ${CONF} || exit 203
		#echo "ok"
		echo -n "Aktiviere vorherigen Apt-Proxy, falls vorhanden ... "
		sed -i -e 's%###\(.*\)%\1%' ${CONF} || exit 204
		echo "ok"
		apt-get update && exit 0
	else
		echo " FEHLER: Zeile nicht gefunden."
	fi
	
	exit 20
fi

if [ ${ACTION} = "merge" ]; then
	if ! [ -f "$FLAG" ]; then
		echo "Datei $FLAG nicht gefunden - Einbinden des Proxy nicht möglich. Abbruch." >&2 
		exit 31
	fi
	if ! [ -f "$APT_LIST" ]; then
		echo "Datei $APT_LIST nicht gefunden - Einbinden des Proxy nicht möglich. Abbruch." >&2 
		exit 32
	fi
	MAS_APT_PROXY=$(cat $FLAG)
	echo -n "Aktiviere Apt-Proxy $MAS_APT_PROXY in $APT_LIST ... "
	sed -i -e "s%http://%http://${MAS_APT_PROXY}%g" ${APT_LIST} && echo "ok." && apt-get update && exit 0
	exit 30

fi

