#!/bin/bash
# Martin Schniewind 2008, http://www.schniewind-it.de
# Nimmt Änderungen an Firefox' und Thunderbirds prefs.js des aktuellen Benutzers vor,
# um den network.protocol-handler zu konfigurieren.

# Firefox finden:
FF=/usr/bin/firefox
if ! test -x $FF; then
	FF=/usr/bin/firefox2
	test -x $FF || FF=""
fi
# Thunderbird finden:
TB=/usr/bin/thunderbird
if ! test -x $TB; then
	TB=/usr/bin/mozilla-thunderbird
	test -x $TB || TB=""
fi

AS_ROOT=no
[ $UID -eq 0 ] && AS_ROOT=yes

# prefs.js ermitteln
if [ $AS_ROOT = "yes" ]; then
	# prefs.js (TB) finden
	PREFS_TB=$(find /etc/thunderbird/profile/ -name prefs.js -print)
	# prefs.js (FF) finden
	PREFS_FF=$(find /etc/firefox*/profile/  -name prefs.js -print | head -n 1)
else
	# prefs.js (TB) finden
	PREFS_TB=$(find $HOME/.mozilla-thunderbird/  -maxdepth 2 -name prefs.js -print)
	[ -z "$PREFS_TB" ] && PREFS_TB=$(find $HOME/.thunderbird/  -maxdepth 2 -name prefs.js -print)
	# prefs.js (FF) finden
	PREFS_FF=$(find $HOME/.mozilla/firefox/  -maxdepth 2 -name prefs.js -print)
fi

check_msg () {
	# $1 = Programmname
	# $2 = Pfad des Handlers, der eingetragen werden soll ($FF oder $TB)
	# $3 = Pfad der prefs.js, die angepasst werden soll
	# Return: 0 wenn ok, 1 wenn nicht
	echo "Passe die Einstellungen von $1 an:"
	if test -z "$2"
	then
		echo "\"$2\" nicht gefunden! Keine Anpassung von $1 möglich."
		return 1
	else
		echo "Einzutragender protocol-handler: $2"
	fi
	if test -z "$3"
	then
		echo "$1-Einstellungen nicht gefunden. Keine Anpassung von $1 möglich."
		return 1
	else
		echo "$1-Benutzerprofil(e):"
		echo $3
	fi
	
	if [ $AS_ROOT = "no" ]; then
		# testen, ob das Programm läuft:
		while $(ps -ef | grep -v "$1" | grep -qi "$1"); do
			echo "Bitte beenden Sie zunächst $1."
			echo -n "Drücken Sie dann ENTER zum Fortfahren oder Strg+C zum Abbrechen. "
			read ANT || return 1
			break
		done
		
		echo -n "Korrigiere $1-Einstellungen \"network.protocol-handler.app\"? [j/N] "
		read ANT
		case ${ANT:-n} in j|J) return 0;; *) return 1;; esac
		return 9
	else
		# als root: Immer 0 zurückgeben, weil egal ist, ob TB/FF laufen, und weil wir die Änderung
		# in jedem Falle durchführen wollen.
		return 0
	fi
}

modify () {
	# $1 = Pfad(e) der prefs.js, die angepasst werden soll(en)
	# $2 = Pfad des Handlers, der eingetragen werden soll ($FF oder $TB)
	# $3 = anzupassende(s) Protokoll(e) (ftp, http, https bzw. mailto
	for pref in $1
	do
		echo "bearbeite $pref ..."
		keybase='network.protocol-handler.app'
		# Schluessel anlegen
		for prot in $3
		do
			key=$keybase.$prot
			# Schluessel bereits vorhanden?
			#echo -n "grep $key $pref: " && 	grep "$key" "$pref"
			# geaendert auf Gebrauch von sed -i wegen Rechteproblem bei AS_ROOT=y
			if grep -q "$key" "$pref"; then
				echo "entferne Schluessel: $key"
				sed -i -e "s/userpref(\"$key,.*//" "$pref"
#				npref="$pref".$$
#				echo "entferne Schluessel: $key (via $npref)"
#				mv "$pref" "$npref" || return 2
#				grep -v "$key" "$npref" > "$pref" || return 3
#				chmod 600 "$pref"
			else
				echo "lege schluessel an: $key = $2"
				sed -i -e "s/userpref(\"$key,.*/userpref(\"$key\", \"$2\");/" "$pref"
			fi
#			echo "lege schluessel an: $key = $2"
#			echo "user_pref(\"$key\", \"$2\");" >> "$pref"
		done
	done
	echo "Fertig."
	echo
}

install_extensions () {
	# $1 = Programmname
	# Die Erweiterungen werden im Verzeichnis des Users 1000 und - wenn von root gerufen - in /etc/skel abgelegt
		
	cd /etc/firefox/profile
	wget download.schniewind-it.de/LINUX/ffxpi.tar.gz && \
		tar xzf ffxpi.tar.gz && rm ffxpi.tar.gz && mv unpacked extensions
	
	
	wget download.schniewind-it.de/LINUX/tbxpi.tar.gz
	
	if [ $AS_ROOT = "no" ]; then
		# entpacken ins eigene HOME-Verzeichnis
		
		return 0
	else
	fi
	
	
	# Installationsverzeichnisse finden
	DIR=$(locate firefox-bin)
	[ -z "$DIR" ] && updatedb && DIR=$(locate firefox-bin)
	FF_INSTALLDIR=$(dirname "$DIR")
	
	DIR=$(locate thunderbird-bin)
	TB_INSTALLDIR=$(dirname "$DIR")
	
	return
	
	# FIXME: Unfertig!
	
	echo "Lade Wörterbücher für FF/TB-Version >= 3 herunter ..."
	# Für FF ab Version 3, TB ab Version 3
	wget https://addons.mozilla.org/de/firefox/downloads/latest/3077/addon-3077-latest.xpi
	VERSION=$(FF -version)
	read MOZ FFNAME FFVER <<< "$VERSION"
	if test ${FFVER:0:1} = "3"; then
		echo -n "Installiere Hunspell-Wörterbuch für Firefox ... "
		$FF -install-global-extension /tmp/mozdic/german*.xpi && echo "ok."
	fi
	VERSION=$(TB -version)
	read TBNAME TBVER <<< "$VERSION"
	if test ${TBVER:0:1} = "3"; then
		echo -n "Installiere Hunspell-Wörterbuch für Thunderbird ... "
		$TB -install-global-extension /tmp/mozdic/german*.xpi && echo "ok."
		
	elif test ${TBVER:0:1} = "2"; then
		# für TB Version 2
		echo "Lade Wörterbuch für TB-Version < 3 herunter ..."
		wget http://www.thunderbird-mail.de/dateien/Dictionaries/woerterbuch_deutsch_de-de_myspell-1.5-tb.xpi
		echo -n "Installiere MySpell-Wörterbuch für Thunderbird ... "
		$TB -install-global-extension /tmp/mozdic/woerterbuch*.xpi && echo "ok."
	fi
	
	# temporäre Dateien und Verzeichnisse löschen
	cd /tmp
	rm -rf mozdic
}

check_msg "Thunderbird" "$FF" "$PREFS_TB" && modify "$PREFS_TB" "$FF" "ftp http https"
check_msg "Firefox" "$TB" "$PREFS_FF" && modify "$PREFS_FF" "$TB" "mailto"
#install_spellcheck
#TODO: weitere Erweiterungen, z.B. gnome-open??