#!/bin/bash
# Anpassungen für Ubuntu-Installationen
# Martin Schniewind, 2008-2020, http://www.schniewind-it.de
#
# Alle Skripte, die im selben Verzeichnis wie dieses Skript liegen, und mit "mas-" beginnen,
# werden in die Variable MAS_SCRIPTS aufgenommen und zur Ausführung angeboten.
#
# Die Konfiguration der Anpassungen werden in Dateien mit Namen mas-configure-XXX-RELEASE-NO.cfg
# abgelegt; diese Dateien werden zum Einlesen Angeboten.
#
# Fehler-Logbuch:
LOGFILE=/tmp/$(basename "$0" .sh).log

# Update der Paketlisten erzwingen, auch wenn das bereits von diesem Skript als erledigt vermerkt ist
FORCE_UPDATE=0

# APT-Proxy verwenden?
APT_PROXY="none"
#APT_PROXY="192.168.113.4"

# alle mas-Skripte im aktuellen Verzeichnis ermitteln
MAS_SCRIPTS="$(ls $(dirname $0)/mas-*.sh | grep -v $(basename $0))"

DONELIST=/tmp/mas-configure.done
touch $DONELIST

exitmsg() {
	echo "$1" >&2
	echo "$1" >> "$LOGFILE"
	kill -SIGTERM $$
}
errormsg() {
	echo "$1" >&2
	echo "$1" >> "$LOGFILE"
}
logmsg() {
	echo "$1"
	echo "$1" >>"$LOGFILE"
}

showhelp()  {
cat << EOF
Aufruf: $(basename $0) [-h|--help|-?]
        $(basename $0) [-f | --force-update] [ {-c | --config} KONFIGURATION ]

Dieses Skript nimmt Anpassungen an Ubuntu vor.

Die Anpassungen werden in einer .cfg-Datei konfiguriert. Der relative oder
absolute Pfad einer solchen Datei kann in KONFIGURATION übergeben werden.
Alternativ kann der kennzeichnende Name der Konfiguration angegeben werden,
z.B. "kubuntu-8.04" bei der Datei "mas-configure-kubuntu-8.04.cfg".
Wird die Konfiguration nicht angegeben, so wird sie vom Skript abgefragt.

Weiterhin werden alle im selben Verzeichnis befindlichen Skripte zur
Ausführung angeboten, deren Name mit "mas-" beginnt. Die ausgewählten
Skripte werden zuallerletzt ausgeführt.

Das Skript muss von "root" ausgefuehrt werden.
EOF
}
showhelp_old()  {
echo "Aufruf: $(basename $0) [-h|--help|-?]

Dieses Skript nimmt folgende Anpassungen an Ubuntu vor:
"
[ -n "$ADD_REPOS" ]	&& echo -e "Hinzufuegen von Paketquellen:\n$ADD_REPOS \n"
[ -n "$EXEC1" ]		&& echo -e "Ausfuehren von:\n$EXEC1 \n"
[ -n "$REMOVE" ]	&& echo -e "Entfernen der Pakete:\n$REMOVE \n"
[ -n "$INSTALL" ]	&& echo -e "Installation der Pakete:\n$INSTALL \n"
[ -n "$EXEC9" ]		&& echo -e "Ausfuehren von:\n$EXEC9 \n"
[ -n "$MAS_SCRIPTS" ]	&& echo -e "Optional: Ausfuehren von:\n$MAS_SCRIPTS \n"
echo "
Das Skript muss von \"root\" ausgefuehrt werden."
}

backupfile() {
	# legt eine Sicherungskopie der Datei in $1 an;
	# gibt den Namen der Sicherungsdatei zurück
	F="$1"
	test -e "$F" || exitmsg "Sichern von $F gescheitert: Datei existiert nicht!"
	N=1
	while test -e "$F.$N"
	do
		N=$(( N + 1 ))
	done
	cp -p "$F" "$F.$N" || exitmsg "Sichern von $F gescheitert: Kopieren nach $F.$N nicht moeglich."
	echo "$F.$N"
}

homedirs() {
	# gibt alle Home-Verzeichnisse zurück
	cd /
	find /home -maxdepth 1 -type d -print | grep -v "^/home$"
	cd $OLDPWD
}

get_yes(){
	# Stellt die in $1 übergebene Frage und gibt 0 für Ja und 1 für Nein zurück
	# Nimmt den in $2 übergebenen Vorgabewert für die Antwort (J oder N).
	DEF=${2:-J}
	DEF_CHOICE="[J/n]"
	test $DEF = "N" && DEF_CHOICE="[j/N]"
	echo -n "$1 $DEF_CHOICE "
	read ANT
	case ${ANT:-$DEF} in j|J) return 0;; *) return 1;; esac
}

get_config() {
	# $1 ist beinhaltet die beim Aufruf angegebene Konfiguration
	#echo "get_config $1"
	MYDIR=$(dirname "$0")
	CFGLIST="/tmp/cfg.list"
	RELEASE=$(lsb_release -r -s)
	while true; do
		# beim vorherigen Durchlauf wurde "Abbrechen" gewählt:
		[ "$CFG" = "Abbrechen" ] && return 1
		# CFG ist absoulter Pfad
		test -f "$CFG" && break
		# CFG ist relativer Pfad
		test -f "$MYDIR/$CFG" && CFG=$MYDIR/$CFG && break
		# CFG ist Konfigurations-Kurzname
		test -f "$MYDIR/mas-configure-$CFG.cfg" && CFG="$MYDIR/mas-configure-$CFG.cfg" && break
		# CFG ist garnichts: Benutzer fragen
		echo -e "Bitte wähle eine der folgenden Konfigurationen aus\n"
		find "$MYDIR" -type f -name "mas-configure-*-${RELEASE}.cfg" -print | sed -e 's%.*-configure-\(.*\).cfg%\1%' > $CFGLIST
		echo "Abbrechen" >> $CFGLIST
		cat -b $CFGLIST
		echo -e -n "\nBitte Nummer angeben: "
		read NR
		case "$NR" in
			[0-9])	CFG=$(head -n $NR "$CFGLIST" | tail -1);;
			*)	echo "Ungültige Eingabe. Bitte wiederholen!";;
		esac
	done

	#echo "$CFG"
	return 0
}

# Aufruf untersuchen
CFG="nofile"
while [ $# -ne 0 ]; do
	case "$1" in
		-h | -\? | --help)	showhelp && exit 0;;
		-f | --force-update)	FORCE_UPDATE=1;;
		-c | --config)		shift; CFG="$1";;
	esac
	shift
done

# Sind wir 'root'?
if test ${UID:-9999} -ne 0; then
	echo "Dieses Skript muss von 'root' ausgefuehrt werden. Bitte Root-Passwort eingeben:"
	sudo "$0" $@
	exit $?
fi

# Konfigurationsdatei setzen und einlesen:
#echo "rufe get_config ..."
get_config "$CFG" || exit 2
source "$CFG"
#echo -e "Config = $CFG\nTest-Ende"; exit

#internal field separator setzen:
OLDIFS=$IFS
IFS="
"

# Paketquellen hinzufuegen:
logmsg "Füge Paketquellen hinzu ..."
for s in $ADD_REPOS
do
    grep -q "$s" $DONELIST || { logmsg "$s" && eval $s && echo "$s" >> $DONELIST; }
done

# ggf. APT-Proxy einstellen
RESET_APT_PROXY=n
if [ "$APT_PROXY" != "none" ]; then
	if [ -x ./mas-configure-aptproxy.sh ]; then
	  ping -c1 "$APT_PROXY" >/dev/null || APT_PROXY=""
	  ./mas-configure-aptproxy.sh -e "$APT_PROXY" && RESET_APT_PROXY=y && echo "apt-get update" >> $DONELIST
	fi
fi

# Paketlisten aktualisieren:
logmsg "Aktualisiere Paketlisten ..."
if ( ! grep -q "apt-get update" $DONELIST ) || [ $FORCE_UPDATE -eq 1 ]; then
	apt-get update || exitmsg "Das Aktualisieren der Paketlisten ist fehlgeschlagen."
	echo "apt-get update" >> $DONELIST
else
	logmsg "	... bereits erledigt."
fi

# Liste zu installierender Pakete prüfen:
echo "prüfe die Verfügbarkeit der zu installierenden Pakete ..."
for p in ${INSTALL}
do
    if ! grep -q "check package $p" $DONELIST
    then
	[ ${p:0:1} = "#" ] && continue
	echo -n "$p : "
	apt-cache show $p >/dev/null || exitmsg "Paket '$p' kann nicht installiert werden. Bitte Konfiguration im Skript anpassen."
	echo "ok."
	echo "check package $p" >> $DONELIST
    fi
done

# Liste der auszufuehrenden mas-Skripte erstellen
DOLIST="/tmp/mas-configure.do"
test -f $DOLIST && rm -f $DOLIST
touch $DOLIST
BLACKLISTS="$MAS_SCRIPT_BLACKLIST $EXEC1 $EXEC9"
for f in $MAS_SCRIPTS; do
	# Steht das Skript auf einer der Blacklist?
	SCRIPT=$f
	[ ${f:0:2} = "./" ] && SCRIPT=${f:2:999}
	#echo "Ist $SCRIPT in der Blacklist? Antwort = ${BLACKLISTS/*$SCRIPT*}"
	[ -z "${BLACKLISTS/*$SCRIPT*}" ] && continue

	# Vorgabe setzen, falls in früherem Lauf bereits gesetzt:
	DEF=N; grep -q $f $DOLIST && DEF=J
	get_yes "Skript $f ausfuehren?" "$DEF" && echo $f >> $DOLIST
done

# Jetzt entfernen wir alle Pakete, die erstmal weg muessen:
for p in ${REMOVE}
do
	[ ${p:0:1} = "#" ] && continue
	s="apt-get remove --purge $p"
	grep -q "$s" $DONELIST || { logmsg "Entferne $s" && eval $s && echo "$s" >> $DONELIST; }
done

# Ausfuehren der EXEC1-Skripte
for s in $EXEC1
do
    grep -q "EXEC1 $s" $DONELIST || { logmsg "ausfuehren von $s" && eval $s && echo "EXEC1 $s" >> $DONELIST; }
done

# Nun werden alle zu installierenden Pakete installiert, wobei brutal JA auf alle Fragen
# angenommen wird:
PACKAGES=""
for p in ${INSTALL}
do
    [ ${p:0:1} = "#" ] && continue
    if ! grep -q "install $p" $DONELIST
    then
	# Blockinstallation:
	PACKAGES="$PACKAGES $p"
# Einzelinstallation deaktiviert 2009-12-18
#    	logmsg "Installiere $p ..."
#	apt-get --install-recommends install -y $p || exitmsg "Installieren von Paket '$p' ist gescheitert."
#	echo "install $p" >> $DONELIST
    fi
done
logmsg "Installiere $PACKAGES ..."
eval apt-get --install-recommends install -y $PACKAGES || exitmsg "Installieren von Paketen '$PACKAGES' ist gescheitert."
#echo $PACKAGES | xargs apt-get --install-recommends install -y $PACKAGES || exitmsg "Installieren von Paketen '$PACKAGES' ist gescheitert."

# Blockinstallation: Ausfuehrung in DONELIST vermerken
for p in ${INSTALL}
do
    [ ${p:0:1} = "#" ] && continue
    grep -q "install $p" $DONELIST || echo "install $p" >> $DONELIST
done


# Ausfuehren der EXEC9-Skripte
for s in $EXEC9
do
	logmsg "Ausfuehren von $s ..."
	grep -q "EXEC9 $s" $DONELIST || { eval $s && echo "EXEC9 $s" >> $DONELIST; }
done

# Ausfuehren der mas-Skripte
for s in $(cat $DOLIST)
do
	logmsg "Ausfuehren von $s ..."
	grep -q "mas $s" $DONELIST || { eval $s |& tee -a "$LOGFILE" && echo "mas $s" >> $DONELIST; }
done

IFS=$OLDIFS

if [ $RESET_APT_PROXY = y ]; then
	./mas-configure-aptproxy.sh -d
fi

# Schlussmeldung
logmsg "

Fertig."
