#!/bin/bash

# Eine Gastsitzung ist in 18.04 mit gdm nicht mehr verfügbar;
# wir basteln eine Umgehungslösung

# Sind wir 'root'?
if test ${UID:-9999} -ne 0; then
        echo "Dieses Skript muss von 'root' ausgefuehrt werden. Bitte Root-Passwort eingeben:"
        sudo "$0" $@
        exit $?
fi

# Ist der Benutzer "guest" vorhanden?
GUEST=$(grep guest /etc/passwd)
if [ -n "$GUEST" ]; then
    echo "Der Benutzer \"guest\" ist bereits vorhanden:"
    echo "======================================================================================"
    echo "$GUEST"
    grep guest /etc/groups
    echo "======================================================================================"
    read -p "Diesen Benutzer ersetzen? [j|N]" ANT
    [ "$ANT" != "j" ] && exit 1
    # Benutzer guest zunächst löschen
    if ! userdel -r guest; then
	echo "Beim Löschen des Benutzers \"guest\" sind Fehler aufgetreten. Deshalb machen wir hier nicht weiter." >&2
	exit 101
    fi 
fi

# Anpassung der globalen Rechte-Maske empfehlen, so dass "others" KEINE Rechte haben
UMASK=$(grep umask /etc/profile | cut -f2 -d" ")
[ -z "$UMASK" ] && UMASK=$(umask)
# vierstellige Zahl erzeugen, falls dreistellig
[ "1$UMASK" -lt 9999 ] && UMASK="0$UMASK"
UMASK_CHANGED=n

if [ "${UMASK:3:1}" != "7" ]; then
	echo -n "Mit der gegenwärtigen Systemeinstellung (umask=$UMASK) könnte jeder Gast alle Dateien lesen. Soll diese Voreinstellung geändert werden? [J|n] " 
	read ANT
	if [ "${ANT,,}" = "j" ]; then
		sed -i -e 's/^umask /#umask /' /etc/profile || exit 201
		echo "umask 027" >> /etc/profile || exit 202
		echo "umask 027 eingetragen in /etc/profile"
		UMASK_CHANGED=j
	fi
fi

# Gastkonto anlegen
#useradd -mb /tmp -s /bin/false -c "Gast-Sitzung" -G cdrom,plugdev,netdev,audio,video guest || exit 301
useradd -mb /tmp -s /bin/false -c "Gast-Sitzung" -G cdrom,plugdev guest || exit 301
passwd -d guest || exit 302

# Policy-Kit Regel erstellen, die der Gruppe guest den Reboot und Shutdown verbietet
echo "erstelle PolicyKit-Regel für Reboot und PowerOff"
POLKITVERSION=$(pkexec --version | cut -f3 -d" ")
POLKITVERSION_MAIN=${POLKITVERSION:0:1}
POLKITVERSION_SUB=${POLKITVERSION:2:3}
# bis 0.105 PKLA-DAtei anlegen, ab 0.106 Rules-Datei
if [ ${POLKITVERSION_MAIN} -gt 0 -o ${POLKITVERSION_SUB} -gt 105 ]; then

	echo "erstelle Regel für PolicyKit Version $POLKITVERSION_MAIN.$POLKITVERSION_SUB"
	echo 'polkit.addRule(function(action, subject) {
    if (action.id == "org.freedesktop.login1.reboot" ||
        action.id == "org.freedesktop.login1.reboot-multiple-sessions") {
        if (subject.isInGroup("adm")) {
            return polkit.Result.YES;
        } else {
            return polkit.Result.NO;
        }
    } else if (action.id == "org.freedesktop.login1.power-off" ||
               action.id == "org.freedesktop.login1.power-off-multiple-sessions") {
        if (subject.isInGroup("guest")) {
            return polkit.Result.NO;
        } else {
            return polkit.Result.YES;
        }
    }
});' > /usr/share/polkit-1/rules.d/61-restrict-shutdown.rules
	chmod o+r //usr/share/polkit-1/rules.d/61-restrict-shutdown.rules

else

	echo "erstelle PKLA-Datei für PolicyKit-Version $POLKITVERSION_MAIN.$POLKITVERSION_SUB"
	echo '[Disable shutdown/etc for groups restricted and guest]
Identity=unix-group:restricted;unix-group:guest
Action=org.freedesktop.login1.reboot;org.freedesktop.login1.reboot-multiple-sessions;org.freedesktop.login1.power-off;org.freedesktop.login1.power-off-multiple-sessions
ResultAny=no
ResultInactive=no' > /etc/polkit-1/localauthority/50-local.d/61-restrict-shutdown.pkla
	chmod o+r /etc/polkit-1/localauthority/50-local.d/61-restrict-shutdown.pkla

fi


echo "
Das Gast-Konto wurde erfolgreich eingerichtet."
[ $UMASK_CHANGED = "n" ] && exit 0

echo -a "\a
WICHTIG! Die bereits vorhandenen Daten aller Benutzer sind noch für Gast-Benutzer lesbar. Um dies zu ändern, führe \"cd && chmod -R o-r,o-w,o-x *\" aus!"
sleep 2

exit 0
