#!/bin/bash
# Installiert acerhk und dkms dafür aus ppa
# nur für Ubuntu 12.04 
# Martin Schniewind, November 2012
# http://www.schniewind-it.de
# Quellen:
# http://wiki.ubuntuusers.de/Acer_Hotkeys
# http://forum.ubuntuusers.de/topic/acer-travelmate-291lci-funknetzwerk-nicht-akti/2/#post-2670605
# http://wiki.ubuntuusers.de/Acer_Hotkeys/DKMS

DIST=$(lsb_release -r -s)
PPA="ppa:cogito-16/ppa"
PROG="acerhk"
PACKAGES="build-essential linux-headers module-assistant debhelper acerhk-source "

if test $UID -ne 0; then
	echo "Dieses Skript muss von root aufgerufen werden!" >&2
	exit 9
fi

if ! test ${DIST} = "12.04"; then
	echo "Dieses Skript ist nur für Ubuntu 12.04, nicht für $DIST. Abbruch." >&2
	exit 1
fi


echo -n "Hotkey-Parameter einrichten für:
	1) Acer Aspire 5630
	2) Acer Extensa 2902LMi (nur WLAN, kein Bluetooth)
	3) Acer Travelmate 291 LMi
	4) Acer Travelmate 292 LCi
	5) Acer Travelmate 4000
	6) FSC Amilo 1650(G)
	7) Medion MD96500/MD97000/MD97600/MD98000 	
	-) (keine Angabe = automatisch)
	
Auswahl: "
read ANT

case "$ANT" in 
	1) PARAM="acerhk force_series=2020 usedritek=1";;
	2) PARAM="acerhk force_series=290 usedritek=1";;
	3) PARAM="acerhk force_series=290 usedritek=1";;
	4) PARAM="acerhk force_series=290 usedritek=1 verbose=1";;
	5) PARAM="acerhk force_series=4000 usedritek=1";;
	6) PARAM="acerhk force_series=5020 autowlan=1";;
	7) PARAM="acerhk force_series=95400 autowlan=1";;
	*) PARAM="";;
esac
	
echo "Paketquelle für $PROG hinzufügen ..."
add-apt-repository $PPA || exit 2
[ -x ./mas-configure-aptproxy.sh ] && ./mas-configure-aptproxy.sh --merge /etc/apt/sources.list.d/cogito*.list

echo "Paketlisten aktualisieren ..."
apt-get update || exit 4

echo "$PROG herunterladen und installieren ..."
apt-get --yes --install-recommends install $PACKAGES || exit 5

# Installation des Quellen
cd /usr/src
sudo tar -xjf acerhk.tar.bz2 || exit 101
mv modules acerhk-0.5.35

cat << EOF > acerhk-0.5.35/dkms.conf
PACKAGE_NAME=acerhk
PACKAGE_VERSION=0.5.35

DEST_MODULE_LOCATION=/extra
BUILT_MODULE_NAME=acerhk
BUILT_MODULE_LOCATION=acerhk/

MAKE="'make' -C acerhk/ all"
CLEAN="'make' -C acerhk/ clean"
AUTOINSTALL="yes"
EOF

# mittels DKMS kompilieren und einrichten
dkms add -m acerhk -v 0.5.35 		|| exit 110
dkms build -m acerhk -v 0.5.35 		|| exit 111
dkms install -m acerhk -v 0.5.35	|| exit 112

# automatisches Ladens des Moduls
echo "options acerhk $PARAM" > /etc/modprobe.d/acerhk.conf	|| exit 201
grep -q acerhk /etc/modules || echo acerhk >> /etc/modules	|| exit 202

# Modul jetzt laden:
modprobe acerhk || exit 211

# WLAN-LED jetzt einschalten
echo 1 > /proc/driver/acerhk/wirelessled

# WLAN-LED immer beim Start einschalten
sed -i -'/exit 0/ i\
echo 1 > /proc/driver/acerhk/wirelessled
' /etc/rc.local || exit 221


echo "Fertig."
exit 0

