#!/bin/bash
# Im aktuellen Verzeichnis müssen die deb-Pakete liegen

if test $UID -ne 0; then
	echo "Dieses Skript muss von root aufgerufen werden!" >&2
	exit 9
fi

DEB_LPR=$(ls ./*lpr*.deb)
DEB_CUPS=$(ls ./*cupswrapper*.deb)
DEB_FAXLPD=$(ls ./*faxlpd*.deb)
DEB_FAXCUPS=$(ls ./*faxcups*.deb)
DEB_SCAN=$(ls ./brscan*.deb)

#DEBS="mfc5460cnlpr-1.0.1-1.i386.deb mfc5460cncupswrapper-1.0.1-1.i386.deb brscan2-0.2.4-0.i386.deb"
#FAXDEBS="brmfcfaxlpd-1.0.0-1.i386.deb brmfcfaxcups-1.0.0-1.i386.deb"

# auf 64-bit-Systemen die Kompatibilitätsbibliotheken installieren
if [ $(uname -m) = "x86_64" ]; then
	apt-get install ia32-libs && exit 101
fi

# neu und ungetestet: 2009-10-15
INSTALL_FROM_LOCAL=1
if test -z ${DEB_LPR}; then
	INSTALL_FROM_LOCAL=0
	#echo "LPR-Paket nicht gefunden - Abbruch" >&2          && exit 1
fi
if test -z ${DEB_CUPS}; then
	INSTALL_FROM_LOCAL=0
	#echo "CUPS-Wrapper-Paket nicht gefunden - Abbruch" >&2 && exit 2
fi
if test $INSTALL_FROM_LOCAL -eq 0; then
	echo -n "LPR-Paket bzw. CUPS-Wrapper-Paket nicht lokal vorhanden - installiere Ubuntu-Pakete..."
	PACK_LIST=""
	for P in $(apt-get search brother-lpr | tr -s " " | cut -d" " -f2); do
		echo -n "."
		DRIVER_PACK=${P##*-}
		MODELS=$(apt-get show $P | grep "for models")
		echo -e "Treiberpaket \"$DRIVER_PACK\":\n     $MODELS"
		PACK_LIST="${PACK_LIST}${DRIVER} "
	done
	
	echo -e "\nBitte Treiber-Paket mittels Nummer auswählen:"
	N=0
	for DRIVER_PACK in $PACK_LIST; do
		N=$(( N + 1 ))
		echo "    ${N})    $DRIVER_PACK"
	done
	echo -e -n "\nAuswahl: "
	read ANT
	if test ${ANT:-0} = "0"; then
		echo "Installation abgebrochen."
		exit 20
	fi
	
	DRIVER_PACK=$(echo $PACK_LIST | cut -d" " -f ${ANT})
	echo "Installiere Treiber-Paket $DRIVER_PACK ..."
	apt-get --install-recommends install -y brother-lpr-drivers-${DRIVER_PACK}
	apt-get --install-recommends install -y brother-cups-wrapper-${DRIVER_PACK}
	
	exit
fi

INSTALL_FAX=N
test -n ${DEB_FAXLPD}  && echo "Fax-Paket (lpd) gefunden:  $DEB_FAXLPD" && INSTALL_FAX=J
if test $INSTALL_FAX = J; then
	test -n ${DEB_FAXCUPS} && echo "Fax-Paket (CUPS) gefunden: $DEB_FAXCUPS"
	echo ""
	echo -n "Gefundene Fax-Treiber installieren? [j/N] "
	read ANT || exit 3
	case ${ANT:-N} in n|N) INSTALL_FAX=N ;; esac
fi

MODEL=$(echo ${DEB_CUPS%lpr*} | tr "[:lower:]" "[:upper:]")
echo -n "Drucker-Modell: [$MODEL] "
read ANT
test -n ${ANT} && MODEL=${ANT}

echo -n "Wenn der Drucker über das Netzwerk angeschlossen ist:
Wie lautet seine IP-Adresse: [leer = kein Netzwerkdrucker] "
read IP

if ! test -d /var/spool/lpd; then
	mkdir /var/spool/lpd || exit 1
fi
if ! test -d /usr/share/cups/model; then
	mkdir /usr/share/cups/model || exit 2
fi

for p in $DEB_LPR $DEB_CUPS $DEB_SCAN $DEB_FAXLPD $DEB_FAXCUPS
do
	dpkg -i --force-all $p || exit 5
done

# Anschluss umstellen auf Netzwerk
if test -n "$IP"; then
 	echo -n "Drucker-Anschluss auf $IP umstellen... "
 	lpadmin -p $MODEL -v lpd://$IP/binary_p1 || exit 10
 	echo "ok."
 	if test $INSTALL_FAX = J; then
 		echo -n "Fax-Anschluss auf $IP umstellen... "
 		lpadmin -p BRFAX -v lpd://$IP/binary_p1 || exit 11
 		echo "ok."
 		echo -n "unsichere Dateirechte anpassen..."
 		chmod 755 /usr/lib/cups/filter/brfaxfilter || exit 12
 		echo "ok."
 	fi
 fi
 

# Scanner konfigurieren, wenn Scannertreiberpaket vorliegt:
test -z "$DEB_SCAN" && exit
echo "Konfiguriere Scanner..."

# Udev-Regel für USB-Scanner hinzufügen:
RULE_FILE=/lib/udev/rules.d/40-libsane.rules
RULE_LINES='
# Brother scanners
ATTRS{idVendor}=="04f9", ENV{libsane_matched}="yes"
'
RULE_MATCH_LINE='# The following rule will disable'
echo -n "Udev-Regel für Brother-Scanner einfügen in $RULE_FILE ..."
sed -i -e "s/$RULE_MATCH_LINE/$RULE_LINES $RULE_MATCH_LINE/" "$RULE_FILE" && echo " ok."



# Scanner-IP konfigurieren, wenn als Netzwerkgerät
test -z "$IP" && echo "Fertig." && exit

# welches brsaneconfig-Programm haben wir?
for i in 5 4 3 2 " "; do
	BRSC=$(which brsaneconfig$i)
	[ -n "$BSC" ] && break
done
[ -z "$BSC" ] && echo "Programm brsaneconfig-Version nicht gefunden. Abbruch" >&2 && exit 110

# Modell-Name aus Modellliste ermitteln
# brsaneconfig2 gibt mit "-q" eine Liste der gültigen Modellnamen aus.
# Der Modellname steht in Anführungszeichen und hat einen Bindestrich drin
NUMMER=$($BRSC -q | sed -e 's/-//' | grep $MODEL | cut -f2-3 -d" ")
if test -z "${NUMMER}"; then
	echo "Scanner-Modell konnte nicht ermittelt werden leider - Abbruch" >&2 && exit 20
fi
SCANNER=$($BRSC -q | grep " $NUMMER " | cut -f3 -d" " | sed -e 's/"//g')
if test -z ${SCANNER}; then
	echo "Scanner-Modell konnte nicht ermittelt werden leider - Abbruch" >&2 && exit 21
fi

echo -n "Scanner auf $IP einstellen... "
$BRSC -a name=$MODEL model=$SCANNER ip=$IP || exit 30
echo "ok."

echo ""
echo "Fertig."

