#!/bin/bash

# Installiert mein Fernwartungsprogramm global mit Desktop-Datei
# TODO: Testen!

SCRIPT_URL="https://download.schniewind-it.de/FERNWARTUNG/Linux/Fernwartung%20Schniewind.sh"
SCRIPT_BASENAME="Fernwartung Schniewind.sh"
INSTALL_DIR="/usr/share/fernwartung-schniewind"
X11VNC_DIR=/tmp/fernwartung
X11VNC_BIN=x11vnc
X11VNC_PACKAGE=x11vnc
X11VC_PATH=""

#############################
# installierten x11vnc finden
function search_vnc()
{
    X11VNC_PATH=""
    X11VNC_PATH=`which ${X11VNC_BIN}`
    if [ "$?" -gt 0 ]; then
    	[ -e "$INSTALL_DIR/$X11VNC_BIN" ] && X11VNC_PATH="$INSTALL_DIR/$X11VNC_BIN"
    fi
    if [ -z "$X11VNC_PATH" ]; then
		echo "search_vnc: Konnte x11vnc nicht auf dem System finden, starte Installation ..."
		load_vnc
		return
    else
		if [ -x ${X11VNC_PATH} ]; then
			echo "search_vnc: x11vnc ist bereits vorhanden und ausfuehrbar ... [${X11VNC_PATH}]"
		fi
    fi
}

#############################
# x11vnc aus dem Netz laden
function load_vnc()
{
	apt --yes install $X11VNC_PACKAGE || exit 101
}

#############################
# Installieren:
# 1.) INSTALL_DIR anlegen
# 2.) dieses Skript kopieren nach INSTALL_DIR
# 3.) Icon herunterladen nach /usr/share/icons
# 4.) Desktop-Datei anlegen unter /usr/share/applications
#
function do_install() {
	# verwendet die globalen Variablen INSTALL_DIR, X11VNC_PATH, X11VNC_DIR und X11VNC_BIN
	local ICON_DIR="/usr/share/icons"
	local APP_DIR="/usr/share/applications"
	local X11VNC_INSTALL_BIN=""
	
	# 1) INSTALL_DIR anlegen
	echo -n "do_install: lege Verzeichnis an: $INSTALL_DIR"
	mkdir -p "$INSTALL_DIR" || return 10
	echo " ... ok."
	
	# 2) Skript herunterladen nach $INSTALL_DIR
	if ! wget --output-document="$INSTALL_DIR/$SCRIPT_BASENAME" "$SCRIPT_URL"; then
		echo "do_install: Das Herunterladen von \"$SCRIPT_URL\" ist fehlgeschlagen."
		return 12
	#2b) Berechtigungen setzen auf 755
	elif ! chmod 755 "$INSTALL_DIR/$SCRIPT_BASENAME"; then
		echo "do_install: Das Setzen der Berechtigungen auf \"$INSTALL_DIR/$SCRIPT_BASENAME\" ist fehlgeschlagen."
		return 13
	fi
		
	# 3) Ikon für den Starter festlegen
	[ -d "$ICON_DIR" ] || mkdir -p "$ICON_DIR"
	if ! cd "$ICON_DIR"; then
		echo "do_install: Verzeichnis \"$ICON_DIR\" existiert nicht. Installation wird abgebrochen." >&2
		return 16
	fi
	#    Kann ich mein Logo herunterladen?
	local ICON="schniewind_55x50_4c-mitBG.png"
	test -e "$ICON" || wget http://download.schniewind-it.de/LINUX/$ICON
	if ! test -e "$ICON" ; then
		# Das Herunterladen hat nicht geklappt.
		# Ist eines meiner Lieblings-Icons auf dem System vorhanden?
		# Wenn nein: dann Platzhalter "none" verwenden
		ICON_DIR="/usr/share/pixmaps"
		ICONS="gnome-term-linux.png gnome-xterm.png gnome-term.png tsclient.png none"
		for ICON in $ICONS; do
			[ -r "$ICON_DIR/$ICON" ]  && break
		done
		[ "$ICON" = "none" ]  && echo "do_install: Keins der bevorzugten Icons im System gefunden." >&2
	fi
	
	# 4) Desktop-Datei erzeugen
	[ -d "$APP_DIR" ] || mkdir -p "$APP_DIR"
	echo "\
#!/usr/bin/env xdg-open
[Desktop Entry]
Version=1.0
Type=Application
Terminal=false
Exec=\"$INSTALL_DIR/Fernwartung\ Schniewind.sh\"
Name=Fernwartung Schniewind
Comment=Fernwartung mittels x11vnc - funktioniert nur nach telefonischem Kontakt, siehe https://www.schniewind-it.de
Icon=$ICON_DIR/$ICON
" > $APP_DIR/fernwartung_schniewind.desktop

	if ! chmod u+x $APP_DIR/fernwartung_schniewind.desktop; then
		echo "do_install: Das Anlegen eines Starters in \"$APP_DIR\" ist fehlgeschlagen. Installation wird abgebrochen." >&2
		return 30
	fi

}

if test $UID -ne 0; then
	echo "Dieses Skript muss von root aufgerufen werden. Installation wird abgebrochen "
	exit -1
fi

search_vnc

do_install

exit 0


