#!/bin/bash
# Ab Ubuntu 22.04!
# Installiert Firefox aus dem Mozillateam-PPA und ersetzt die Snap-Installation
# Sorgt für eingeeignetes APT-Pinning und für die Berücksichtung bei unattended-upgrades.
# weitere Quellen:
#  https://wiki.ubuntuusers.de/Firefox/Installation/PPA/
#  https://www.omgubuntu.co.uk/2022/04/how-to-install-firefox-deb-apt-ubuntu-22-04
# Martin Schniewind, Mai 2023
# http://www.schniewind-it.de

PPA="ppa:mozillateam/ppa"
PROG="Firefox (deutsch) aus PPA"
PACKAGES="firefox firefox-locale-de"

if test $UID -ne 0; then
    echo "Dieses Skript muss von root aufgerufen werden!" >&2
    exit 9
fi

# Ermitteln: War Firefox als Snap in Benutzung? Dann Profiles sichern:
for HOMEDIR in $(ls -1 /home); do
	SNAP_PROFILE=$HOMEDIR/snap/firefox/common/.mozilla/firefox/
	NATIVE_PROFILE=$HOMEDIR/.mozilla/firefox
	if test -d "$SNAP_PROFILE"; then
		echo "Firefox war als Snap in Verwendung bei $HOMEDIR:"
		# altes Profilverzeichnis auf Desktop sichern
		if test -d "$NATIVE_PROFILE"; then
			if ! source "$HOMEDIR/.config/user-dirs.dirs"; then
				XDG_DESKTOP_DIR="$HOMEDIR/Desktop"
				echo "lege Desktop mangels Konfiguration fest auf $XDG_DESKTOP_DIR" >&2
			fi
			echo -n "sichere Profilverzeichnis $NATIVE_PROFILE nach $XDG_DESKTOP_DIR/Firefox-Profilsicherung ..."
			mv "$NATIVE_PROFILE" "$XDG_DESKTOP_DIR/Firefox-Profilsicherung/" && echo " fertig."
		fi
		# Snap-Profilverzeichnis kopieren
		cp -p "$SNAP_PROFILE" "$NATIVE_PROFILE"
	fi
done

# zunächst entfernen
echo "$PROG entfernen ..."
apt remove firefox
snap remove firefox

echo "PPA als Paketquelle installieren und APT-System konfigurieren ..."
# PPA einrichten
apt-add-repository -y "$PPA"
# APT Pinning anlegen
echo "\
Package: * 
Pin: release o=LP-PPA-mozillateam
Pin-Priority: 100

Package: firefox*
Pin: release o=LP-PPA-mozillateam
Pin-Priority: 1001" > /etc/apt/preferences.d/mozillateam
# Unattendes Upgrades konfigurieren
echo 'Unattended-Upgrade::Allowed-Origins:: "LP-PPA-mozillateam:${distro_codename}";' > /etc/apt/apt.conf.d/51unattended-upgrades-firefox
# Pinning überprüfen
if apt policy firefox | grep "\*\*\*" | grep snap; then
	echo "FEHLER: Pinning für Firefox ist Fehlgeschlagen. Bitte prüfe /etc/apt/preferences.d/mozillateam!" >&2
fi

echo "Paketlisten aktualisieren ..."
apt-get update || exit 4

echo "$PROG herunterladen und installieren ..."
apt-get install -y $PACKAGES || exit 5

echo "Fertig."
exit 0

