#!/bin/bash
# Installiert LibreOffice aus PPA
# geht ab Ubuntu 18.04
# Martin Schniewind, August 2019
# http://www.schniewind-it.de

REPO="ppa:libreoffice/libreoffice"
VERSION="6.1"
PROG="LibreOffice"
#INSTALL_DIR="/usr/lib/libreoffice"
PACKAGES="libreoffice
libreoffice-sdbc-firebird"

DO_INSTALL=yes
INSTALL_CLIPARTS=no

showhelp() {
	cat <<- EOF
	Syntax: $(basename $0) [--install-cliparts]
	
	Installiert LibreOffice aus PPA - die gewünschte Version wird abgefragt.
	
	Die Option "--install-cliparts" bewirkt, dass die OpenClipart-Gallery aus den
	Distributionsquellen installiert bzw. aktualisiert wird.
	
	EOF
	exit
}

while [ -n "$1" ]; do
	case "$1" in
		--install-cliparts|--cliparts)
			INSTALL_CLIPARTS=yes
			shift
			;;
		*)
			showhelp
			;;
	esac	
done

if test $UID -ne 0; then
	echo "Dieses Skript muss von root aufgerufen werden."
	exit
fi

	 
if [ $DO_INSTALL = yes ]; then

	while /bin/true; do
		echo -n "Zu installierende Version: [$VERSION] "
		read -t 5 ANT
		if [ $? -gt 128 ]; then
			:
		elif [ -z "$ANT" ]; then
			:
		#elif [ ${#ANT} -ne 3 ]; then
		#	echo "Die Eingabe muss genau drei Zeichen lang sein. Bitte wiederholen."
		#	continue
		elif [ "x${ANT/[0-9].[0-9]}x" != "xx" ]; then
			echo "Die Eingabe muss das Format #.# haben (z.B. 6.0, 6.2). Bitte wiederholen."
			continue
		else
			VERSION="$ANT"
		fi
		
		#echo "Ausgewählte Version: $VERSION"
		break
	done

	echo -n "vorhandene LibreOffice-Version durch $VERSION ersetzen? [j/N] "
	read -t 5 ANT
	[ ${ANT^^} = "J" ] || exit 0
	
	echo "Paketquelle für $PROG hinzufügen ..."
	if ! apt-add-repository -y "${REPO}-${VERSION/./-}"; then
		echo "Die Paketquelle $REPO konnte nicht hinzugefügt werden. Abbruch." >&2
		exit 2
	fi

	echo "Paketlisten aktualisieren ..."
	apt-get update || exit 4
	
	# neue Version installieren
	echo "$PROG herunterladen und installieren ..."
	apt-get -y install $PACKAGES || exit 5
	echo "Fertig."
fi


# Openclipart aus dem Distributions-Repository installieren
if [ $INSTALL_CLIPARTS = yes ]; then
	echo "Installiere OpenClipart-Sammlung ..."
	apt-get --yes --no-install-recommends install openclipart-libreoffice
fi


exit 0

