#!/bin/bash
# Installiert und konfiguriert OpenOffice.org in der nicht-debian-Version
# auf einem Debian-artigen System.
# Martin Schniewind, 2007 - 2009
# http://www.schniewind-it.de

VERSION="3.2.1"
#VERSION="3.2.0"	# defekt (Base / insertRow() )
#VERSION="3.1.1"
BASEPACKAGE=openoffice.org3-base
ARC=$(uname -m)
ARC_PART="LinuxIntel_install_de_deb"
[ "$ARC" = "x86_64" ] && ARC_PART="Linux_x86-64_install-deb_de"
URL="ftp://sunsite.informatik.rwth-aachen.de/pub/mirror/OpenOffice/localized/de/${VERSION}/OOo_${VERSION}_${ARC_PART}.tar.gz"
TARBALL=$(basename $URL)
#DIR="DEBS" # Das stimmt nicht immer! S.u.
DO_INSTALL=yes
DO_CONFIGURE=yes
INSTALL_CLIPARTS=no
TEMP=/tmp

showhelp() {
	cat <<- EOF
	Syntax: $(basename $0) [-c | --configure] [--install-cliparts] [-t TEMPDIR ]
	
	Laedt OpenOffice.org Version $VERSION herunter. Deinstalliert vorhandene Debian-
	Versionen von OpenOffice.org, installiert die offizielle Version und legt
	zusaetzliche Start-Verknuepfungen in /usr/bin an.
	
	Installiert - falls erforderlich - die distributionseigene OpenClipart-Sammlung
	und bindet sie in die neue OpenOffice.org-Installation ein.
	
	Die Option "--configure-only" bewirkt, dass OpenOffice.org weder deinstalliert
	noch installiert wird. Es werden lediglich die Konfigurationsaufgaben ausgefuehrt
	(Wiederherstellung der Start- und Gallery-Verknuepfungen, Prüfung/Reparatur der
	symbolischen Links auf OOo-Systembibliotheken)
	
	Die Option "--install-cliparts" bewirkt, dass die OpenClipart-Gallery aus den
	Distributionsquellen installiert bzw. aktualisiert wird.
	
	EOF
	exit
}

while [ -n "$1" ]; do
	case "$1" in
		-c|--configure*)
			DO_INSTALL=no
			shift
			;;
		--install-cliparts|--cliparts)
			INSTALL_CLIPARTS=yes
			DO_CONFIGURE=no
			shift
			;;
		-t)	shift
			TEMP=${1:-/tmp}
			shift
			;;
		*)
			showhelp
			;;
	esac	
done

if test $UID -ne 0; then
	echo "Dieses Skript muss von root aufgerufen werden."
	exit
fi

# temporäres Verzeichnis:
if ! test -d "$TEMP"; then
	if ! mkdir -p "$TEMP"; then
		echo "Konnte temporäres Verzeichnis \"$TEMP\" nicht anlegen. Abbruch." >&2
		exit 19
	fi
	REMOVE_TEMP=1
else
	REMOVE_TEMP=0
fi

if [ $DO_INSTALL = yes ]; then

	echo -n "aktuelle OpenOffice.org-Version durch $VERSION ersetzen? [j/N] "
	read ANT
	[ ${ANT:-N} = j -o ${ANT:-N} = j ] || exit 0

	if test -f "$TEMP/$TARBALL"; then
		:
	elif test -f "$PWD/$TARBALL"; then
		test -f "$TEMP/$TARBALL" || ln -s "$PWD/$TARBALL" "$TEMP"
	else
		echo "Lade $PROG herunter ..."
		cd "$TEMP"
		wget $URL || exit 1
	fi
	
	cd "$TEMP"
	
	# Stammverzeichnis des Tar-Archivs ermitteln:
	DIR=$(tar -tzf $TARBALL | grep "DEBS" | head -1)
	
	# Tarball entpacken
	echo "Entpacke heruntergeladenes Archiv ..."
	tar -xzvf $TARBALL || exit 1
	
	cd "$DIR" || exit 1
	
	# vorhandene Openoffice-Pakete entfernen, wenn noch ein
	# Paket mit Versionsnummer <> $VERSION installiert ist.
	# Dies wird auch kubuntu-desktop deinstallieren, aber das ist ok;
	# kubuntu-desktop ist ein Meta-Paket, das von openoffice.org2 und
	# openoffice.org-kde abhängt.
	echo "Entferne vorhandene OpenOffice.org-Version <> ${VERSION:0:3} ... "
	if dpkg --list 'openoffice*' | grep "^i" | grep -q -v "${VERSION:0:3}"
	then
		echo
		# Liste installierter OOo-Pakete erstellen
		OOOPKGS=$(COLUMNS=250 dpkg-query -l 'openoffice*' | grep "^i" | tr -s " " | cut -d" " -f2)
		if [ -z "$OOOPKGS" ]; then
			echo "Konnte installierte Pakete nicht ermitteln" >&2
			exit 3
		fi
		apt-get remove $OOOPKGS || exit 2

	else
		echo "	nicht vorhanden."
	fi
	
	# neue Version installieren
	echo "Installiere offizielle OpenOffice.org-Version ${VERSION} aus ${DIR} ..."
	dpkg --install ./*.deb || exit 3
	dpkg --install ./desktop-integration/*.deb || exit 4
fi

# temporäres Verzeichnis ggf. löschen
cd /
if test ${REMOVE_TEMP} -eq 1; then
	test -d "$TEMP" && rm -rf "$TEMP"
fi

# Installationsverzeichnis ermitteln:
INSTALL_DIR=$(dpkg-query --listfiles $BASEPACKAGE | grep "openoffice" | head -1)
if ! test -d "$INSTALL_DIR"; then
	echo "Ermitteln des Installationsverzeichnisses ist fehlgeschlagen ($INSTALL_DIR)" >&2 && exit 5
else
	echo "Installationsverzeichnis: $INSTALL_DIR"
fi

if [ "$DO_CONFIGURE" = "yes" ]; then
	# Start-Verknuepfungen im Debian-Stil in /usr/bin ablegen;
	# dies repliziert das oo-wrapper-Skript von Ubuntu/Debian fuer
	# die OpenOffice.org-Version 2.0.1
	WRAPPER="/usr/bin/ooo-wrapper"
	echo "erstelle Wrapper-Skript $WRAPPER ..."
	[ -e "$WRAPPER" ] && {
		BAKFILE=$(mktemp "$WRAPPER".XXXXXX)
		cat "$WRAPPER" >> "$BAKFILE"
	}

# Debian-Wrapper-Skript erzeugen:
cat > "$WRAPPER" << EOF
#!/usr/bin/perl -w
#
# ooffice - Wrapper script for OpenOffice.org
# Modified to match installation of OOo $VERSION from original OOo deb packs
# by Martin Schniewind (http://www.schniewind-it.de)

# Define system installation directory
my \$SystemInstallDir = '$INSTALL_DIR';
# Suffix for parallel installable versioning
my \$BinSuffix = '';
# ooo-build version
my \$OOO_BUILDVERSION = '$VERSION';
EOF

cat >> "$WRAPPER" << "EOF"
if ($SystemInstallDir =~ /^@/) {
    $SystemInstallDir = '/usr/lib/ooo-2.0';
    $BinSuffix = '';
}

my $Binary = 'soffice';
if (-x "$SystemInstallDir/program/ooqstart") {
    $Binary = 'ooqstart';
    $ENV{OOO_EXTRA_ARG} ||= '';
}

my @ooo_argv;
my $widgets_set;
while ($ARGV[0]) {
    $_ = shift;
    if (m/^--widgets-set/) {
	$widgets_set = shift;
	(defined $widgets_set) || die "Error: The option --widgets-set requires a value\n" .
	                            "For example: --widgets-set gtk\n";
    } elsif (m/^--version/) {
	print "This is oficcial OpenOffice.org Version $OOO_BUILDVERSION\n";
	exit 0;
    } elsif (m/^-(base|calc|draw|impress|math|web|writer)$/ && $Binary eq "ooqstart") {
        $ENV{OOO_EXTRA_ARG} = $_;
    } elsif (m/^-fromtemplate$/ && $Binary eq "ooqstart") {
        $ENV{OOO_EXTRA_ARG} = "slot:5500";
    } elsif (m/^system:\//) {
	s/^system:/file:\/\//;
        push @ooo_argv, $_;
    } elsif (m/^system:/) {
	use Cwd;
	my $dir = getcwd;
	s/^system:/file:\/\/$dir\//;
        push @ooo_argv, $_;
    } else {
        push @ooo_argv, $_;
    }
}

if (!@ooo_argv) {
    my $arg;
    if ($0 =~ m/\/oo(calc|draw|impress|math|web|writer|base)$BinSuffix$/) {
        $arg = "-$1";
    } elsif ($0 =~ m/\/oofromtemplate$BinSuffix$/) {
        $arg = "slot:5500";
    }

    if ($arg) {
        if ($Binary eq "soffice") {
            push @ooo_argv, "$arg";
	} else {
	    $ENV{OOO_EXTRA_ARG} = $arg;
	}
    }
}

if (defined $widgets_set) {
    $ENV{SAL_USE_VCLPLUGIN} = $widgets_set;
}

# FIXME: the following two fixes should be done by OOo itself
# create the user config directory  with safe rights 700 if it we find
# the right path and the directory does not exist
if (open BOOTSTRAPRC, "$SystemInstallDir/program/bootstraprc") {
    while (my $line = <BOOTSTRAPRC>) {
	chomp $line;
    	if (($line =~ m/^\s*UserInstallation\s*=\s*([^\s]*)\s*$/) && ($1)) {
	    my $userConfDir=$1;
	    $userConfDir =~ s|\$SYSUSERCONFIG|$ENV{HOME}|;
	    $userConfDir =~ s|file://||;
	    mkdir ($userConfDir,0700) unless (-d $userConfDir);
	    last;
	}
    }
    close BOOTSTRAPRC;
}
# touch ~/.recently-used with safe rights 700 if it does not exist
if (! -f "$ENV{HOME}/.recently-used") {
    open (RECENTLY_USED, ">$ENV{HOME}/.recently-used") &&
    close RECENTLY_USED &&
    chmod 0600, "$ENV{HOME}/.recently-used";
}
	
if (!(-f '/proc/version')) {
    print STDERR "\n\n --- Warning - OO.o will not work without a mounted /proc filesystem --- \n\n\n";
}

if (defined $ENV{LANG}) {
    if ($ENV{LANG} =~ /^th/) {
	# turn off autohinting for thai (Ubuntu #35305).
	$ENV{SAL_AUTOHINTING_PRIORITY} = "0";
    }
}

# And here we go.
exec "$SystemInstallDir/program/$Binary", @ooo_argv

EOF

	chmod 755 "$WRAPPER"

	echo "Lege Startverknuepfungen in /usr/bin an ..."
	for prog in writer calc base draw impress math fromtemplate
	do
		echo "	$prog ..."
		#echo -e "#!/bin/bash\nopenoffice.org2.2 -$prog \$@ &" > /usr/bin/oo${prog}
		#chmod a+x /usr/bin/oo$prog
		LINK=/usr/bin/oo${prog}
		[ -e "$LINK" ] && rm -f "$LINK"
		ln -s "$WRAPPER" "$LINK"
	done
	[ -e /usr/bin/soffice ] && { rm -f /usr/bin/ooffice 2>/dev/null; ln -s /usr/bin/soffice /usr/bin/ooffice; }
fi
# Ende DO_CONFIGURE = yes

# Openclipart aus dem Distributions-Repository installieren
if [ $INSTALL_CLIPARTS = yes ]; then
	echo "Installiere OpenClipart-Sammlung ..."
	apt-get --yes --no-install-recommends install openclipart-openoffice.org

	# Openclipart aus dem Installationspfad der Distribution einbinden.
	# Dies geschieht, indem die Galerie-Themen (*.thm, *.sgv, *.sdv) aus $SOURCE
	# in das entsprechende Verzeichnis der neuen Installation $TARGET
	# verknuepft werden.
	SOURCE="/usr/lib/openoffice/basis3.2/share/gallery/"
	TARGET="$INSTALL_DIR/basis-link/share/gallery"
	DO_LINK=yes
	if ! test -d "$SOURCE"; then
		echo "Clipart-Galerie ist nicht in $SOURCE installiert." >&2
		DO_LINK=no
	else
		echo "Binde OpenClipart-Sammlung ein ..."
		if ! test -d "$TARGET"; then
			echo "Zielverzeichnis $TARGET nicht gefunden!. Das ist ein Fehler in diesem Skript :-(" >&2
			DO_LINK=no
		fi
		if [ $DO_LINK = yes ]; then
			for thm in "$SOURCE"/*.thm
			do
				THMBN=$(basename $thm .thm)
				echo -n "$THMBN "
				for suffix in thm sdg sdv
				do
					test -L "$TARGET/$THMBN.$suffix" && rm -f "$TARGET/$THMBN.$suffix"
					ln -s "$SOURCE/$THMBN.$suffix" "$TARGET/$THMBN.$suffix"
				done
			done
			echo "fertig."
		fi
	fi
fi
# Ende INSTALL_CLIPARTS = yes

exit 0

############### AUSSER BETRIEB ###########################
# Symbolische Links in $INSTALL_DIR/program reparieren.
# Problem trat mit OOo 2.4.1 auf; soffice fand einige Bibliotheken
# nicht, weil diese Links fehlten.
echo -n "Pruefe/repariere Bibliothek-Links in $INSTALL_DIR/program ..."
cd $INSTALL_DIR/program || exit 3
echo
for f in *.so*.1.1; do
	echo -n "	$f ... "
	LINK=${f/.1.1/}
	test -L "$LINK" && echo "(vorhanden: $LINK)" && continue
	ln -s $f "$LINK" && echo "angelegt: $LINK"
done
for f in *.so.[0-9]; do
	echo -n "	$f ... "
	LINK=${f/.[0-9]/}
	test -L $LINK && echo "(vorhanden: $LINK)" && continue
	ln -s $f $LINK && echo "angelegt: $LINK"
done


exit
