#!/bin/bash
# Installiert VirtualBox
# Martin Schniewind, Oktober 2008 - März 2011
# http://www.schniewind-it.de

DIST=$(lsb_release -c -s)
SRC="deb http://download.virtualbox.org/virtualbox/debian $DIST contrib"
SRC_LIST="virtualbox.list"
KEY_ADD="wget -q http://www.virtualbox.org/download/oracle_vbox_2016.asc -O- | apt-key add -"
VENDOR="Oracle"
#VENDOR="Sun"

PROG="VirtualBox"
# Note: Ubuntu users might want to install the dkms package (not available on Debian) to ensure that the VirtualBox host kernel module (vboxdrv) is properly updated if the linux kernel version changes during the next apt-get upgrade.
PACKAGES="dkms"

if test $UID -ne 0; then
	echo "Dieses Skript muss von root aufgerufen werden!" >&2
	exit 9
fi

if test -z ${DIST}; then
	echo "Der Codename des Linux konnte nicht ermittelt werden. Abbruch." >&2
	exit 1
fi

echo "Paketquelle für VirtualBox hinzufügen ..."
echo "$SRC" > /etc/apt/sources.list.d/$SRC_LIST || exit 2
[ -f ./mas-configure-aptproxy.sh ] && ./mas-configure-aptproxy.sh --merge /etc/apt/sources.list.d/$SRC_LIST

echo "Schlüssel des Repository hinzufügen ..."
eval $KEY_ADD || exit 3

echo "Paketlisten aktualisieren ..."
apt-get update || exit 4

# aktuelle Version finden
VBOX_PACKAGE=$(apt-cache search virtualbox | grep "$VENDOR" | sort | tail -1 | tr -s " " | cut -f1 -d" ")
if [ -z "$VBOX_PACKAGE" ]; then
	echo "aktuelle VirtualBox-Version nicht gefunden (dies ist ein Skriptfehler)." >&2
	exit 12
fi
PACKAGES="$VBOX_PACKAGE $PACKAGES"

echo "$VBOX_PACKAGE herunterladen und installieren ..."
apt-get --install-recommends install -y $PACKAGES || exit 5

if [ "$DIST" = "karmic" ]; then
	# USB-Fix Siehe: https://help.ubuntu.com/community/VirtualBox/USB
	echo "passe /etc/fstab an..."
	vGid=$(grep vboxusers /etc/group|cut -d\: -f3) # Determine the devgid for the vboxusers group
	if [ "$vGid" ] && grep -q usbfs /etc/fstab ; then
		echo "none /proc/bus/usb usbfs devgid=${vGid},devmode=664 0 0" >>/etc/fstab
		mount -a
	fi
fi

# Benutzer mit UID 1000 der Gruppe vboxusers hinzufügen
USER=$(grep 1000 /etc/passwd | cut -f1 -d:)
if [ -n "$UID" ]; then
	echo -n "fuege Benutzer \"$USER\" zur Gruppe vboxusers hinzu ... "
	usermod -a -G vboxusers $USER && echo "ok."
fi
echo "Fertig."
exit 0

