#!/bin/bash
# OEM-Weitergabe eines Systems vorbereiten
# Martin Schniewind 2023, https://www.schniewind-it.de

PACKAGES="oem-config oem-config-slideshow-ubuntu oem-config-gtk ubiquity ubiquity-frontend-gtk ubiquity-ubuntu-artwork"

# farbige Ausgaben vorbereiten
if test -t 1; then # if terminal
    ncolors=$(which tput > /dev/null && tput colors) # supports color
    if test -n "$ncolors" && test $ncolors -ge 8; then
        termcols=$(tput cols)
        bold="$(tput bold)"
        underline="$(tput smul)"
        standout="$(tput smso)"
        normal="$(tput sgr0)"
        black="$(tput setaf 0)"
        red="$(tput setaf 1)"
        green="$(tput setaf 2)"
        yellow="$(tput setaf 3)"
        blue="$(tput setaf 4)"
        magenta="$(tput setaf 5)"
        cyan="$(tput setaf 6)"
        white="$(tput setaf 7)"
    fi
fi


# Sind wir 'root'?
if test ${UID:-9999} -ne 0; then
	echo "${red}Dieses Skript muss von 'root' ausgefuehrt werden. Bitte Root-Passwort eingeben:${normal}"
	sudo "$0" $@
	exit $?
fi

# Benutzer "oem" anlegen
if ! grep -q "^oem:" /etc/passwd; then
	echo "${green}Anlegen des Benutzers 'oem' - bitte Kennwort anlegen (z.B. 'oem123') ...${normal}"
	adduser --uid 29999 oem || exit 110
	usermod -a -G adm,cdrom,sudo,dip,plugdev,lpadmin,oem,sambashare oem || exit 112
fi

# Pakete installieren
OEM_CONFIG=absent
echo -n "${green}Ist oem-config-prepare schon verfügbar? "
if which oem-config-prepare > /dev/null; then
	echo "ja.${normal}"
	OEM_CONFIG=present
else
	echo "Nein. Installieren der erforderlichen Pakete ...${normal}"
	apt update
	apt -y install $PACKAGES || exit 210
fi

# Benutzer löschen außer root und oem
USERS=$(grep "/bin/bash$" /etc/passwd | grep -v "^oem" | grep -v root| cut -d":" -f1)
echo -n "${green}Löschen der überzähligen Benutzer $USERS? [j|N] ${normal}"
read ANT
if test "${ANT,,}" = "j"; then
	for USER in $(echo $USERS); do
		echo -n "${green}Lösche $USER ...${normal}"
		userdel --force --remove "$USER" && echo "${green}ok.${normal}"
	done
fi

# Falls wir schon ausschließlich den User "oem" haben: OEM-Installation beim nächsten Boot aktivieren
echo -n "${green}Sind alle anderen Benutzer außer oem gelöscht? ${green}"
HOME_CNT=$(ls -1 /home | wc -l)
if test -d /home/oem && test ${HOME_CNT:0} -eq 1; then
	echo "ja. Ausführen von oem-config-prepare${normal}"
	oem-config-prepare
else
	echo "nein. Wir unternehmen weiter nichts.${normal}"
fi
echo "${yellow}Fertig und Ende.${normal}"
